Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1249)

Unified Diff: chrome/browser/resources/settings/a11y_page/manage_a11y_page.js

Issue 2200463002: Reorganize accessibility settings. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Finish i18n Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/settings/a11y_page/manage_a11y_page.js
diff --git a/chrome/browser/resources/settings/a11y_page/a11y_page.js b/chrome/browser/resources/settings/a11y_page/manage_a11y_page.js
similarity index 65%
copy from chrome/browser/resources/settings/a11y_page/a11y_page.js
copy to chrome/browser/resources/settings/a11y_page/manage_a11y_page.js
index 2ee16f1d392c79385a03fd02d6ea2abf7aabdf36..3605dada1a5b8b49d3b04c8596e2a9d52a6926fd 100644
--- a/chrome/browser/resources/settings/a11y_page/a11y_page.js
+++ b/chrome/browser/resources/settings/a11y_page/manage_a11y_page.js
@@ -1,21 +1,14 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
/**
* @fileoverview
* 'settings-a11y-page' is the settings page containing accessibility
* settings.
- *
- * Example:
- *
- * <iron-animated-pages>
- * <settings-a11y-page prefs="{{prefs}}"></settings-a11y-page>
- * ... other pages ...
- * </iron-animated-pages>
*/
Polymer({
- is: 'settings-a11y-page',
+ is: 'settings-manage-a11y-page',
properties: {
/**
@@ -27,6 +20,17 @@ Polymer({
},
<if expr="chromeos">
Dan Beam 2016/08/01 20:37:03 isn't this whole page only <if cros>? can you jus
dmazzoni 2016/08/02 03:07:02 You're right, done
+ /**
+ * Whether to show experimental accessibility features.
+ * @private {boolean}
+ */
+ showExperimentalFeatures_: {
+ type: Boolean,
+ value: function() {
+ return loadTimeData.getBoolean('showExperimentalA11yFeatures');
+ },
+ },
+
autoClickDelayOptions_: {
readOnly: true,
type: Array,
@@ -45,21 +49,35 @@ Polymer({
];
},
},
-
- /**
- * Whether to show experimental accessibility features.
- * @private {boolean}
- */
- showExperimentalFeatures_: {
- type: Boolean,
- value: function() {
- return loadTimeData.getBoolean('showExperimentalA11yFeatures');
- },
- }
</if>
},
/** @private */
+ onChromeVoxSettingsTap_: function() {
+ chrome.send('showChromeVoxSettings');
+ },
+
+ /** @private */
+ onDisplayTap_: function() {
+ settings.navigateTo(settings.Route.DISPLAY);
+ },
+
+ /** @private */
+ onAppearanceTap_: function() {
+ settings.navigateTo(settings.Route.APPEARANCE);
+ },
+
+ /** @private */
+ onKeyboardTap_: function() {
+ settings.navigateTo(settings.Route.KEYBOARD);
+ },
+
+ /** @private */
+ onMouseTap_: function() {
+ settings.navigateTo(settings.Route.POINTERS);
+ },
+
+ /** @private */
onMoreFeaturesTap_: function() {
window.open(
'https://chrome.google.com/webstore/category/collection/accessibility');
@@ -1,21 +1,14 @@
/**
* @fileoverview
- * 'settings-a11y-page' is the settings page containing accessibility
+ * 'settings-manage-a11y-page' is the subpage with the accessibility
* settings.

Powered by Google App Engine
This is Rietveld 408576698